@@ -784,6 +784,14 @@ MainWindow::uiClearStatusMessage()
     d->ui->statusBar->clearMessage ();
 }//MainWindow::uiClearStatusMessage
 
+void
+MainWindow::uiShowMessageBox(const QString &msg)
+{
+    QMessageBox dlg;
+    dlg.setText (msg);
+    dlg.exec ();
+}//MainWindow::uiShowMessageBox
+
 void
 MainWindow::onSystrayActivated(QSystemTrayIcon::ActivationReason reason)
 {
